@@ -5,7 +5,7 @@ use warnings;
 use parent qw( Alien::Base );
 use 5.008004;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 
@@ -17,7 +17,7 @@ Alien::DuckDB - Find or build DuckDB
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -26,11 +26,6 @@ Version 0.02
 
  my $ffi = FFI::Platypus->new;
  $ffi->lib(Alien::DuckDB->dynamic_libs);
- 
- # Access version and configuration information
- my $version = Alien::DuckDB->version;
- my $cflags = Alien::DuckDB->cflags;
- my $libs = Alien::DuckDB->libs;
 
 =head1 DESCRIPTION
 
@@ -44,24 +39,6 @@ and Windows (x86_64, arm64).
 
 =head1 METHODS
 
-=head2 version
-
- my $version = Alien::DuckDB->version;
-
-Returns the version of the installed DuckDB library.
-
-=head2 cflags
-
- my $cflags = Alien::DuckDB->cflags;
-
-Returns the compiler flags needed to compile against the DuckDB library.
-
-=head2 libs
-
- my $libs = Alien::DuckDB->libs;
-
-Returns the linker flags needed to link against the DuckDB library.
-
 =head2 dynamic_libs
 
  my @libs = Alien::DuckDB->dynamic_libs;
@@ -105,4 +82,4 @@ Copyright 2024 Chris Prather
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
